public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: Star Zeng <star.zeng@intel.com>
To: edk2-devel@lists.01.org
Cc: Star Zeng <star.zeng@intel.com>, Chao Zhang <chao.b.zhang@intel.com>
Subject: [PATCH] SecurityPkg Tcg2ConfigDxe: Refine debug message and comments
Date: Mon,  9 Jan 2017 13:40:19 +0800	[thread overview]
Message-ID: <1483940419-139088-1-git-send-email-star.zeng@intel.com> (raw)

Cc: Chao Zhang <chao.b.zhang@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Star Zeng <star.zeng@intel.com>
---
 SecurityPkg/Tcg/Tcg2Config/Tcg2ConfigDriver.c | 6 +++---
 SecurityPkg/Tcg/Tcg2Config/Tcg2ConfigImpl.c   | 4 ++--
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/SecurityPkg/Tcg/Tcg2Config/Tcg2ConfigDriver.c b/SecurityPkg/Tcg/Tcg2Config/Tcg2ConfigDriver.c
index 34828eed7d64..050e43a3371d 100644
--- a/SecurityPkg/Tcg/Tcg2Config/Tcg2ConfigDriver.c
+++ b/SecurityPkg/Tcg/Tcg2Config/Tcg2ConfigDriver.c
@@ -137,7 +137,7 @@ InitializeTcg2VersionInfo (
     }
   } else {
     //
-    // EFI variable doesn't exist.
+    // EFI variable doesn't exist or variable size is not expected.
     //
 
     //
@@ -182,7 +182,7 @@ InitializeTcg2VersionInfo (
   //
   // Get the PCD value again.
   // If the PCD value is not equal to the value in variable,
   // the PCD is not DynamicHii type and maps to the setup option.
   //
   PcdTcg2PpiVersion = 0;
   CopyMem (
@@ -191,7 +191,7 @@ InitializeTcg2VersionInfo (
     AsciiStrSize ((CHAR8 *) PcdGetPtr (PcdTcgPhysicalPresenceInterfaceVer))
     );
   if (PcdTcg2PpiVersion != Tcg2Version.PpiVersion) {
-    DEBUG ((DEBUG_WARN, "WARNING: PcdTcgPhysicalPresenceInterfaceVer is not DynamicHii type and maps to TCG2_VERSION.PpiVersion\n"));
+    DEBUG ((DEBUG_WARN, "WARNING: PcdTcgPhysicalPresenceInterfaceVer is not DynamicHii type and does not map to TCG2_VERSION.PpiVersion\n"));
     DEBUG ((DEBUG_WARN, "WARNING: The TCG2 PPI version configuring from setup page will not work\n"));
   }
 
@@ -182,7 +182,7 @@ InitializeTcg2VersionInfo (
   // Get the PCD value again.
   // If the PCD value is not equal to the value in variable,
-  // the PCD is not DynamicHii type and maps to the setup option.
+  // the PCD is not DynamicHii type and does not map to the setup option.
   //
   PcdTcg2PpiVersion = 0;
diff --git a/SecurityPkg/Tcg/Tcg2Config/Tcg2ConfigImpl.c b/SecurityPkg/Tcg/Tcg2Config/Tcg2ConfigImpl.c
index 4432daea81b6..f4a07c642009 100644
--- a/SecurityPkg/Tcg/Tcg2Config/Tcg2ConfigImpl.c
+++ b/SecurityPkg/Tcg/Tcg2Config/Tcg2ConfigImpl.c
@@ -489,7 +489,7 @@ Tcg2VersionInfoCallback (
     // Get the PCD value after EFI_BROWSER_ACTION_SUBMITTED,
     // the SetVariable to TCG2_VERSION_NAME should have been done.
     // If the PCD value is not equal to the value set to variable,
     // the PCD is not DynamicHii type and maps to the setup option.
     //
     PcdTcg2PpiVersion = 0;
     CopyMem (
@@ -501,7 +501,7 @@ Tcg2VersionInfoCallback (
       CreatePopUp (
         EFI_LIGHTGRAY | EFI_BACKGROUND_BLUE,
         &Key,
-        L"WARNING: PcdTcgPhysicalPresenceInterfaceVer is not DynamicHii type and maps to this option!",
+        L"WARNING: PcdTcgPhysicalPresenceInterfaceVer is not DynamicHii type and does not map to this option!",
         L"The version configuring by this setup option will not work!",
         NULL
         );
@@ -489,7 +489,7 @@ Tcg2VersionInfoCallback (
     // the SetVariable to TCG2_VERSION_NAME should have been done.
     // If the PCD value is not equal to the value set to variable,
-    // the PCD is not DynamicHii type and maps to the setup option.
+    // the PCD is not DynamicHii type and does not map to the setup option.
     //
     PcdTcg2PpiVersion = 0;
-- 
2.7.0.windows.1



             reply	other threads:[~2017-01-09  5:40 UTC|newest]

Thread overview: 2+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-01-09  5:40 Star Zeng [this message]
2017-01-09  5:51 ` [PATCH] SecurityPkg Tcg2ConfigDxe: Refine debug message and comments Zhang, Chao B

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1483940419-139088-1-git-send-email-star.zeng@intel.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox